/*******************************************************************************
*
*         USING THE EXTERNAL INTERRUPT 2 TO ENTER AN INTERRUPT SUBROUTINE
*         ---------------------------------------------------------------
*
*   Filename:                                    
*   Autor:                  David Kress
*
*   Version:                1.0
*   Date:                   10.11.2014
*   Built with:             ATMEL AVR Studio 4.14 and AVR-GCC; Optimization -01
*
*   Description:            This programm is a simple example how to detect an
*                           external interrupt on INT2 and entering the
*                           interrupt subroutine. The subroutine will toggle 
*                           a digitalport which can be visualized with an led or
*                           or a dc voltmeter. The interrupt is caused by a
*                           rising edge.
*                           Notice, that this program doesn't contains 
*                           switch debouncing. So it could be, that the led goes
*                           off again immediately.
*                           
*   What you can learn:     - Enabel the external interruptsource INT2
*                           - Configurate INT2 for rising edge interrupt
*                           - Write the subroutine for INT2
*
*   Recommended             - High: 0x99
*   Fuse settings:          - Low:  0xE1
*
*   Schematic:       ___________________
*                   |      ATMEGA32     |
*          Vcc ---->|Vcc                |
*          Vcc ---->|RESET              |
*                   |                   |
*          GND ---->|GND                |
*                   |                   |
*                   |                PA0|----> DOUT
*            \      |                   |
*    GND ---  \o--->|PB2 (INT2/AIN0)    |             
*                   |                   |
*                   |                   |
*
*******************************************************************************/


#include <avr/io.h>
#include <avr/interrupt.h>

int main(void)
{

    DDRA = 0x01;                       // Setup PA1 as output
    PORTB = 0x04;                      // Activate internal pullupressistor of PB2

    GICR |= (1<<INT2);                 // Enable external interrupt INT2
    MCUCSR |= (1<<ISC2);               // INT2 is executed on rising edge
    sei();                             // Set the I-bit in SREG

  
    for(;;);                           // The main loop stays empty and could contain 
                                       // code you want.

    return 0;                          // This line will never be executed

}

// Interrupt subroutine for external interrupt 1
ISR(INT2_vect)							
{
    PORTA ^= 0x01;                     // Toggle PA0
}
